==> ukelli-ui-3.0.0.tgz: package/core/record-render/desc-helper.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React from 'react';
import MapperFilter from './mapper-filter';
/**
 * 具体单独数据的渲染模版
 *
 * @export
 * @class DescHelper
 * @extends {MapperFilter}
 */
var DescHelper = /** @class */ (function (_super) {
    __extends(DescHelper, _super);
    function DescHelper() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DescHelper.prototype.render = function () {
        var _this = this;
        var _a = this.props, _b = _a.keyMapper, keyMapper = _b === void 0 ? [] : _b, _c = _a.record, record = _c === void 0 ? {} : _c, _d = _a.className, className = _d === void 0 ? '' : _d, col = _a.col;
        var row = 0;
        return (React.createElement("div", { className: "desc-container detail-desc " + className + " " + (col ? 'col' : '') }, keyMapper.map(function (mapper, idx) {
            if (!mapper)
                return null;
            var key = mapper.key;
            var title = _this.titleFilter(mapper, idx);
            var text = _this.mapperFilter(mapper, record);
            var isLongText = text ? text.length > 100 : '';
            var _a = mapper.block, block = _a === void 0 ? isLongText : _a;
            if (idx % 2 === 0)
                row += 1;
            if (block)
                row += 1;
            var bgColor = row % 2 !== 0 ? ' odd' : '';
            return (React.createElement("div", { className: "item" + (block ? ' block' : '') + bgColor, key: key },
                React.createElement("div", { className: "t" }, title),
                React.createElement("div", { className: "c" + (isLongText ? ' lg' : '') }, text)));
        })));
    };
    return DescHelper;
}(MapperFilter));
export default DescHelper;

==> ukelli-ui-3.3.1.tgz: package/core/record-render/desc-helper.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React from 'react';
import MapperFilter from './mapper-filter';
/**
 * 具体单独数据的渲染模版
 *
 * @export
 * @class DescHelper
 * @extends {MapperFilter}
 */
var DescHelper = /** @class */ (function (_super) {
    __extends(DescHelper, _super);
    function DescHelper() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DescHelper.prototype.render = function () {
        var _this = this;
        var _a = this.props, _b = _a.record, record = _b === void 0 ? {} : _b, _c = _a.className, className = _c === void 0 ? '' : _c, col = _a.col;
        var columns = this.getColumns();
        var row = 0;
        return (React.createElement("div", { className: "desc-container detail-desc " + className + " " + (col ? 'col' : '') }, columns.map(function (mapper, idx) {
            if (!mapper)
                return null;
            var key = mapper.key;
            var title = _this.titleFilter(mapper, idx);
            var text = _this.mapperFilter(mapper, record);
            var isLongText = text ? text.length > 100 : '';
            var _a = mapper.block, block = _a === void 0 ? isLongText : _a;
            if (idx % 2 === 0)
                row += 1;
            if (block)
                row += 1;
            var bgColor = row % 2 !== 0 ? ' odd' : '';
            return (React.createElement("div", { className: "item" + (block ? ' block' : '') + bgColor, key: key },
                React.createElement("div", { className: "t" }, title),
                React.createElement("div", { className: "c" + (isLongText ? ' lg' : '') }, text)));
        })));
    };
    return DescHelper;
}(MapperFilter));
export default DescHelper;
